@@ -13,6 +13,7 @@ import (
 	"io"
 	"net/http"
 	"net/url"
+	"strings"
 	"time"
 
 	"ariga.io/atlas/sql/migrate"
@@ -20,8 +21,12 @@ import (
 	"github.com/vektah/gqlparser/v2/gqlerror"
 )
 
-// defaultURL for Atlas Cloud.
-const defaultURL = "https://api.atlasgo.cloud/query"
+const (
+	// defaultURL for Atlas Cloud.
+	defaultURL = "https://api.atlasgo.cloud/query"
+	// DefaultProjectName is the default name for projects.
+	DefaultProjectName = "default"
+)
 
 // Client is a client for the Atlas Cloud API.
 type Client struct {
@@ -45,9 +50,23 @@ func New(endpoint, token string) *Client {
 	}
 }
 
+type clientCtxKey struct{}
+
+// NewContext returns a new context with the given Client attached.
+func NewContext(parent context.Context, c *Client) context.Context {
+	return context.WithValue(parent, clientCtxKey{}, c)
+}
+
+// FromContext returns a Client stored inside a context, or nil if there isn't one.
+func FromContext(ctx context.Context) *Client {
+	c, _ := ctx.Value(clientCtxKey{}).(*Client)
+	return c
+}
+
 // DirInput is the input type for retrieving a single directory.
 type DirInput struct {
-	Name string `json:"name"`
+	Slug string `json:"slug,omitempty"`
+	Name string `json:"name,omitempty"`
 	Tag  string `json:"tag,omitempty"`
 }
 
@@ -57,11 +76,11 @@ func (c *Client) Dir(ctx context.Context, input DirInput) (migrate.Dir, error) {
 		payload struct {
 			Dir struct {
 				Content []byte `json:"content"`
-			} `json:"dir"`
+			} `json:"dirState"`
 		}
 		query = `
-		query getDir($input: DirInput!) {
-		   dir(input: $input) {
+		query dirState($input: DirStateInput!) {
+		   dirState(input: $input) {
 		     content
 		   }
 		}`
@@ -146,17 +165,17 @@ type (
 )
 
 // ReportMigrationSet reports a set of migration deployments to the Atlas Cloud API.
-func (c *Client) ReportMigrationSet(ctx context.Context, input ReportMigrationSetInput) error {
+func (c *Client) ReportMigrationSet(ctx context.Context, input ReportMigrationSetInput) (string, error) {
 	var (
 		payload struct {
 			ReportMigrationSet struct {
-				Success bool `json:"success"`
+				URL string `json:"url"`
 			} `json:"reportMigrationSet"`
 		}
 		query = `
 		mutation ReportMigrationSet($input: ReportMigrationSetInput!) {
 		   reportMigrationSet(input: $input) {
-		     success
+		     url
 		   }
 		}`
 		vars = struct {
@@ -165,21 +184,24 @@ func (c *Client) ReportMigrationSet(ctx context.Context, input ReportMigrationSe
 			Input: input,
 		}
 	)
-	return c.post(ctx, query, vars, &payload)
+	if err := c.post(ctx, query, vars, &payload); err != nil {
+		return "", err
+	}
+	return payload.ReportMigrationSet.URL, nil
 }
 
 // ReportMigration reports a migration deployment to the Atlas Cloud API.
-func (c *Client) ReportMigration(ctx context.Context, input ReportMigrationInput) error {
+func (c *Client) ReportMigration(ctx context.Context, input ReportMigrationInput) (string, error) {
 	var (
 		payload struct {
 			ReportMigration struct {
-				Success bool `json:"success"`
+				URL string `json:"url"`
 			} `json:"reportMigration"`
 		}
 		query = `
 		mutation ReportMigration($input: ReportMigrationInput!) {
 		   reportMigration(input: $input) {
-		     success
+		     url
 		   }
 		}`
 		vars = struct {
@@ -188,7 +210,10 @@ func (c *Client) ReportMigration(ctx context.Context, input ReportMigrationInput
 			Input: input,
 		}
 	)
-	return c.post(ctx, query, vars, &payload)
+	if err := c.post(ctx, query, vars, &payload); err != nil {
+		return "", err
+	}
+	return payload.ReportMigration.URL, nil
 }
 
 func (c *Client) post(ctx context.Context, query string, vars, data any) error {
@@ -213,11 +238,17 @@ func (c *Client) post(ctx context.Context, query string, vars, data any) error {
 	}
 	defer req.Body.Close()
 	if res.StatusCode != http.StatusOK {
-		return fmt.Errorf("unexpected status code: %d", res.StatusCode)
+		var v struct {
+			Errors errlist `json:"errors,omitempty"`
+		}
+		if err := json.NewDecoder(res.Body).Decode(&v); err != nil || len(v.Errors) == 0 {
+			return fmt.Errorf("unexpected status code: %d", res.StatusCode)
+		}
+		return v.Errors
 	}
 	var scan = struct {
-		Data   any           `json:"data"`
-		Errors gqlerror.List `json:"errors,omitempty"`
+		Data   any     `json:"data"`
+		Errors errlist `json:"errors,omitempty"`
 	}{
 		Data: data,
 	}
@@ -230,9 +261,19 @@ func (c *Client) post(ctx context.Context, query string, vars, data any) error {
 	return nil
 }
 
-// roundTripper is a http.RoundTripper that adds the Authorization header.
-type roundTripper struct {
-	token string
+type (
+	// errlist wraps the gqlerror.List to print errors without
+	// extra newlines and prefix info added.
+	errlist gqlerror.List
+	// roundTripper is a http.RoundTripper that adds the Authorization header.
+	roundTripper struct {
+		token string
+	}
+)
+
+func (e errlist) Error() string {
+	s := strings.TrimPrefix(gqlerror.List(e).Error(), "input:")
+	return strings.TrimSpace(s)
 }
 
 // RoundTrip implements http.RoundTripper.
