@@ -16,4 +16,17 @@ func init() {
 		schemaInspectCmd(),
 	)
 	Root.AddCommand(schemaCmd)
+	migrateCmd := migrateCmd()
+	migrateCmd.AddCommand(
+		migrateApplyCmd(),
+		migrateDiffCmd(),
+		migrateHashCmd(),
+		migrateImportCmd(),
+		migrateLintCmd(),
+		migrateNewCmd(),
+		migrateSetCmd(),
+		migrateStatusCmd(),
+		migrateValidateCmd(),
+	)
+	Root.AddCommand(migrateCmd)
 }
