@@ -24,9 +24,9 @@ import (
 	"ariga.io/atlas/cmd/atlas/internal/cloudapi"
 	"ariga.io/atlas/cmd/atlas/internal/cmdext"
 	"ariga.io/atlas/cmd/atlas/internal/cmdlog"
-	"ariga.io/atlas/cmd/atlas/internal/lint"
 	cmdmigrate "ariga.io/atlas/cmd/atlas/internal/migrate"
 	"ariga.io/atlas/cmd/atlas/internal/migrate/ent/revision"
+	"ariga.io/atlas/cmd/atlas/internal/migratelint"
 	"ariga.io/atlas/sql/migrate"
 	"ariga.io/atlas/sql/schema"
 	"ariga.io/atlas/sql/sqlcheck"
@@ -40,22 +40,6 @@ import (
 	"github.com/spf13/cobra"
 )
 
-func init() {
-	migrateCmd := migrateCmd()
-	migrateCmd.AddCommand(
-		migrateApplyCmd(),
-		migrateDiffCmd(),
-		migrateHashCmd(),
-		migrateImportCmd(),
-		migrateLintCmd(),
-		migrateNewCmd(),
-		migrateSetCmd(),
-		migrateStatusCmd(),
-		migrateValidateCmd(),
-	)
-	Root.AddCommand(migrateCmd)
-}
-
 // migrateCmd represents the subcommand 'atlas migrate'.
 func migrateCmd() *cobra.Command {
 	cmd := &cobra.Command{
@@ -75,7 +59,6 @@ type migrateApplyFlags struct {
 	logFormat       string
 	lockTimeout     time.Duration
 	allowDirty      bool   // allow working on a database that already has resources
-	fromVersion     string // compute pending files based on this version
 	baselineVersion string // apply with this version as baseline
 	txMode          string // (none, file, all)
 }
@@ -87,9 +70,6 @@ func (f *migrateApplyFlags) migrateOptions() (opts []migrate.ExecutorOption) {
 	if v := f.baselineVersion; v != "" {
 		opts = append(opts, migrate.WithBaselineVersion(v))
 	}
-	if v := f.fromVersion; v != "" {
-		opts = append(opts, migrate.WithFromVersion(v))
-	}
 	return
 }
 
@@ -124,7 +104,7 @@ If run with the "--dry-run" flag, atlas will not execute any SQL.`,
 					if err != nil {
 						return err
 					}
-					set := NewReportProvider(project, envs)
+					set := NewReportProvider(cmd.Context(), project, envs)
 					defer func() { set.Flush(cmd, cmdErr) }()
 					return cmdEnvsRun(envs, setMigrateEnvFlags, cmd, func(env *Env) error {
 						return migrateApplyRun(cmd, args, flags, set.ReportFor(flags, env))
@@ -141,11 +121,9 @@ If run with the "--dry-run" flag, atlas will not execute any SQL.`,
 	addFlagRevisionSchema(cmd.Flags(), &flags.revisionSchema)
 	addFlagDryRun(cmd.Flags(), &flags.dryRun)
 	addFlagLockTimeout(cmd.Flags(), &flags.lockTimeout)
-	cmd.Flags().StringVarP(&flags.fromVersion, flagFrom, "", "", "calculate pending files from the given version (including it)")
 	cmd.Flags().StringVarP(&flags.baselineVersion, flagBaseline, "", "", "start the first migration after the given baseline version")
 	cmd.Flags().StringVarP(&flags.txMode, flagTxMode, "", txModeFile, "set transaction mode [none, file, all]")
 	cmd.Flags().BoolVarP(&flags.allowDirty, flagAllowDirty, "", false, "allow start working on a non-clean database")
-	cmd.MarkFlagsMutuallyExclusive(flagFrom, flagBaseline)
 	cmd.MarkFlagsMutuallyExclusive(flagLog, flagFormat)
 	return cmd
 }
@@ -165,7 +143,7 @@ func migrateApplyRun(cmd *cobra.Command, args []string, flags migrateApplyFlags,
 		}
 	}
 	// Open and validate the migration directory.
-	dir, err := cmdmigrate.Dir(flags.dirURL, false)
+	dir, err := cmdmigrate.Dir(ctx, flags.dirURL, false)
 	if err != nil {
 		return err
 	}
@@ -296,9 +274,13 @@ type (
 )
 
 // NewReportProvider returns a new ReporterProvider.
-func NewReportProvider(project *Project, envs []*Env) *MigrateReportSet {
+func NewReportProvider(ctx context.Context, p *Project, envs []*Env) *MigrateReportSet {
+	c := cloudapi.FromContext(ctx)
+	if p.cfg.Client != nil {
+		c = p.cfg.Client
+	}
 	s := &MigrateReportSet{
-		client: project.cfg.Client,
+		client: c,
 		ReportMigrationSetInput: cloudapi.ReportMigrationSetInput{
 			ID:        uuid.NewString(),
 			StartTime: time.Now(),
@@ -379,7 +361,10 @@ func (s *MigrateReportSet) Flush(cmd *cobra.Command, cmdErr error) {
 	if cmdErr != nil && s.Error == nil {
 		s.StepLogError(cmdErr.Error())
 	}
-	var err error
+	var (
+		err  error
+		link string
+	)
 	switch {
 	// Skip reporting if set is empty,
 	// or there is no cloud connectivity.
@@ -387,23 +372,28 @@ func (s *MigrateReportSet) Flush(cmd *cobra.Command, cmdErr error) {
 		return
 	// Single migration that was completed.
 	case s.Planned == 1 && len(s.Completed) == 1:
-		err = s.client.ReportMigration(cmd.Context(), s.Completed[0])
+		link, err = s.client.ReportMigration(cmd.Context(), s.Completed[0])
 	// Single migration that failed to start.
 	case s.Planned == 1 && len(s.Completed) == 0:
 		s.EndTime = time.Now()
-		err = s.client.ReportMigrationSet(cmd.Context(), s.ReportMigrationSetInput)
+		link, err = s.client.ReportMigrationSet(cmd.Context(), s.ReportMigrationSetInput)
 	// Multi environment migration (e.g., multi-tenancy).
 	case s.Planned > 1:
 		s.EndTime = time.Now()
-		err = s.client.ReportMigrationSet(cmd.Context(), s.ReportMigrationSetInput)
+		link, err = s.client.ReportMigrationSet(cmd.Context(), s.ReportMigrationSetInput)
 	}
-	if err != nil {
+	switch {
+	case err != nil:
 		txt := fmt.Sprintf("Error: %s", strings.TrimRight(err.Error(), "\n"))
 		// Ensure errors are printed in new lines.
 		if cmd.Flags().Changed(flagFormat) {
 			txt = "\n" + txt
 		}
 		cmd.PrintErrln(txt)
+	// Unlike errors that are printed to stderr, links are printed to stdout.
+	// We do it only if the format was not customized by the user (e.g., JSON).
+	case link != "" && !cmd.Flags().Changed(flagFormat):
+		cmd.Println(link)
 	}
 }
 
@@ -415,7 +405,7 @@ func (r *MigrateReport) Init(c *sqlclient.Client, l *cmdlog.MigrateApply, rrw cm
 // RecordTargetID asks the revisions-table to allow or provide
 // the target identifier if cloud reporting is enabled.
 func (r *MigrateReport) RecordTargetID(ctx context.Context) error {
-	if r.CloudEnabled() {
+	if r.CloudEnabled(ctx) {
 		id, err := r.rrw.ID(ctx, operatorVersion())
 		if err != nil {
 			return err
@@ -427,7 +417,7 @@ func (r *MigrateReport) RecordTargetID(ctx context.Context) error {
 
 // Done closes and flushes this report.
 func (r *MigrateReport) Done(cmd *cobra.Command, flags migrateApplyFlags) error {
-	if !r.CloudEnabled() {
+	if !r.CloudEnabled(cmd.Context()) {
 		return logApply(cmd, cmd.OutOrStdout(), flags, r.log)
 	}
 	var (
@@ -488,8 +478,8 @@ func (r *MigrateReport) Done(cmd *cobra.Command, flags migrateApplyFlags) error
 }
 
 // CloudEnabled reports if cloud reporting is enabled.
-func (r *MigrateReport) CloudEnabled() bool {
-	return r.env != nil && r.env.cfg != nil && r.env.cfg.Client != nil && r.env.cfg.Project != ""
+func (r *MigrateReport) CloudEnabled(ctx context.Context) bool {
+	return r.env != nil && r.env.cfg != nil && r.env.cfg.Project != "" && (r.env.cfg.Client != nil || cloudapi.FromContext(ctx) != nil)
 }
 
 func logApply(cmd *cobra.Command, w io.Writer, flags migrateApplyFlags, r *cmdlog.MigrateApply) error {
@@ -520,7 +510,6 @@ type migrateDiffFlags struct {
 	schemas           []string
 	lockTimeout       time.Duration
 	format            string
-	revisionSchema    string // revision schema name
 	qualifier         string // optional table qualifier
 }
 
@@ -531,11 +520,12 @@ func migrateDiffCmd() *cobra.Command {
 		cmd   = &cobra.Command{
 			Use:   "diff [flags] [name]",
 			Short: "Compute the diff between the migration directory and a desired state and create a new migration file.",
-			Long: `'atlas migrate diff' uses the dev-database to re-run all migration files in the migration directory, compares
-it to a given desired state and create a new migration file containing SQL statements to migrate the migration
-directory state to the desired schema. The desired state can be another connected database or an HCL file.`,
-			Example: `  atlas migrate diff --dev-url mysql://user:pass@localhost:3306/dev --to file://schema.hcl
-  atlas migrate diff --dev-url mysql://user:pass@localhost:3306/dev --to file://atlas.hcl add_users_table
+			Long: `The 'atlas migrate diff' command uses the dev-database to calculate the current state of the migration directory
+by executing its files. It then compares its state to the desired state and create a new migration file containing
+SQL statements for moving from the current to the desired state. The desired state can be another another database,
+an HCL, SQL, or ORM schema. See: https://atlasgo.io/versioned/diff`,
+			Example: `  atlas migrate diff --dev-url docker://mysql/8/dev --to file://schema.hcl
+  atlas migrate diff --dev-url "docker://postgres/15/dev?search_path=public" --to file://atlas.hcl add_users_table
   atlas migrate diff --dev-url mysql://user:pass@localhost:3306/dev --to mysql://user:pass@localhost:3306/dbname
   atlas migrate diff --env dev --format '{{ sql . "  " }}'`,
 			Args: cobra.MaximumNArgs(1),
@@ -562,7 +552,6 @@ directory state to the desired schema. The desired state can be another connecte
 	addFlagDevURL(cmd.Flags(), &flags.devURL)
 	addFlagDirURL(cmd.Flags(), &flags.dirURL)
 	addFlagDirFormat(cmd.Flags(), &flags.dirFormat)
-	addFlagRevisionSchema(cmd.Flags(), &flags.revisionSchema)
 	addFlagSchemas(cmd.Flags(), &flags.schemas)
 	addFlagLockTimeout(cmd.Flags(), &flags.lockTimeout)
 	addFlagFormat(cmd.Flags(), &flags.format)
@@ -594,7 +583,7 @@ func migrateDiffRun(cmd *cobra.Command, args []string, flags migrateDiffFlags, e
 	if err != nil {
 		return err
 	}
-	dir, err := cmdmigrate.DirURL(u, false)
+	dir, err := cmdmigrate.DirURL(ctx, u, false)
 	if err != nil {
 		return err
 	}
@@ -742,7 +731,7 @@ This command should be used whenever a manual change in the migration directory
 				return dirFormatBC(flags.dirFormat, &flags.dirURL)
 			},
 			RunE: func(cmd *cobra.Command, args []string) error {
-				dir, err := cmdmigrate.Dir(flags.dirURL, false)
+				dir, err := cmdmigrate.Dir(cmd.Context(), flags.dirURL, false)
 				if err != nil {
 					return err
 				}
@@ -780,7 +769,7 @@ func migrateImportCmd() *cobra.Command {
 				if err := dirFormatBC(flags.dirFormat, &flags.fromURL); err != nil {
 					return err
 				}
-				d, err := cmdmigrate.Dir(flags.fromURL, false)
+				d, err := cmdmigrate.Dir(cmd.Context(), flags.fromURL, false)
 				if err != nil {
 					return err
 				}
@@ -810,11 +799,11 @@ func migrateImportRun(cmd *cobra.Command, _ []string, flags migrateImportFlags)
 	if f := p.Query().Get("format"); f == "" || f == cmdmigrate.FormatAtlas {
 		return fmt.Errorf("cannot import a migration directory already in %q format", cmdmigrate.FormatAtlas)
 	}
-	src, err := cmdmigrate.Dir(flags.fromURL, false)
+	src, err := cmdmigrate.Dir(cmd.Context(), flags.fromURL, false)
 	if err != nil {
 		return err
 	}
-	trgt, err := cmdmigrate.Dir(flags.toURL, true)
+	trgt, err := cmdmigrate.Dir(cmd.Context(), flags.toURL, true)
 	if err != nil {
 		return err
 	}
@@ -930,32 +919,32 @@ func migrateLintRun(cmd *cobra.Command, _ []string, flags migrateLintFlags) erro
 		return err
 	}
 	defer dev.Close()
-	dir, err := cmdmigrate.Dir(flags.dirURL, false)
+	dir, err := cmdmigrate.Dir(cmd.Context(), flags.dirURL, false)
 	if err != nil {
 		return err
 	}
-	var detect lint.ChangeDetector
+	var detect migratelint.ChangeDetector
 	switch {
 	case flags.latest == 0 && flags.gitBase == "":
 		return fmt.Errorf("--%s or --%s is required", flagLatest, flagGitBase)
 	case flags.latest > 0 && flags.gitBase != "":
 		return fmt.Errorf("--%s and --%s are mutually exclusive", flagLatest, flagGitBase)
 	case flags.latest > 0:
-		detect = lint.LatestChanges(dir, int(flags.latest))
+		detect = migratelint.LatestChanges(dir, int(flags.latest))
 	case flags.gitBase != "":
-		detect, err = lint.NewGitChangeDetector(
+		detect, err = migratelint.NewGitChangeDetector(
 			dir,
-			lint.WithWorkDir(flags.gitDir),
-			lint.WithBase(flags.gitBase),
-			lint.WithMigrationsPath(dir.(interface{ Path() string }).Path()),
+			migratelint.WithWorkDir(flags.gitDir),
+			migratelint.WithBase(flags.gitBase),
+			migratelint.WithMigrationsPath(dir.(interface{ Path() string }).Path()),
 		)
 		if err != nil {
 			return err
 		}
 	}
-	format := lint.DefaultTemplate
+	format := migratelint.DefaultTemplate
 	if f := flags.logFormat; f != "" {
-		format, err = template.New("format").Funcs(lint.TemplateFuncs).Parse(f)
+		format, err = template.New("format").Funcs(migratelint.TemplateFuncs).Parse(f)
 		if err != nil {
 			return fmt.Errorf("parse format: %w", err)
 		}
@@ -968,11 +957,11 @@ func migrateLintRun(cmd *cobra.Command, _ []string, flags migrateLintFlags) erro
 	if err != nil {
 		return err
 	}
-	r := &lint.Runner{
+	r := &migratelint.Runner{
 		Dev:            dev,
 		Dir:            dir,
 		ChangeDetector: detect,
-		ReportWriter: &lint.TemplateWriter{
+		ReportWriter: &migratelint.TemplateWriter{
 			T: format,
 			W: cmd.OutOrStdout(),
 		},
@@ -980,7 +969,7 @@ func migrateLintRun(cmd *cobra.Command, _ []string, flags migrateLintFlags) erro
 	}
 	err = r.Run(cmd.Context())
 	// Print the error in case it was not printed before.
-	cmd.SilenceErrors = errors.As(err, &lint.SilentError{})
+	cmd.SilenceErrors = errors.As(err, &migratelint.SilentError{})
 	cmd.SilenceUsage = cmd.SilenceErrors
 	return err
 }
@@ -1022,12 +1011,12 @@ func migrateNewCmd() *cobra.Command {
 	return cmd
 }
 
-func migrateNewRun(_ *cobra.Command, args []string, flags migrateNewFlags) error {
+func migrateNewRun(cmd *cobra.Command, args []string, flags migrateNewFlags) error {
 	u, err := url.Parse(flags.dirURL)
 	if err != nil {
 		return err
 	}
-	dir, err := cmdmigrate.DirURL(u, true)
+	dir, err := cmdmigrate.DirURL(cmd.Context(), u, true)
 	if err != nil {
 		return err
 	}
@@ -1087,11 +1076,7 @@ to be applied. This command is usually used after manually making changes to the
 
 func migrateSetRun(cmd *cobra.Command, args []string, flags migrateSetFlags) (rerr error) {
 	ctx := cmd.Context()
-	dir, err := cmdmigrate.Dir(flags.dirURL, false)
-	if err != nil {
-		return err
-	}
-	files, err := dir.Files()
+	dir, err := cmdmigrate.Dir(ctx, flags.dirURL, false)
 	if err != nil {
 		return err
 	}
@@ -1140,6 +1125,10 @@ func migrateSetRun(cmd *cobra.Command, args []string, flags migrateSetFlags) (re
 	if err != nil {
 		return err
 	}
+	files, err := dir.Files()
+	if err != nil {
+		return err
+	}
 	var version string
 	switch n := len(args); {
 	// Prevent the case where 'migrate set' is called without a version on
@@ -1284,11 +1273,12 @@ func migrateStatusCmd() *cobra.Command {
 }
 
 func migrateStatusRun(cmd *cobra.Command, _ []string, flags migrateStatusFlags) error {
-	dir, err := cmdmigrate.Dir(flags.dirURL, false)
+	ctx := cmd.Context()
+	dir, err := cmdmigrate.Dir(ctx, flags.dirURL, false)
 	if err != nil {
 		return err
 	}
-	client, err := sqlclient.Open(cmd.Context(), flags.url)
+	client, err := sqlclient.Open(ctx, flags.url)
 	if err != nil {
 		return err
 	}
@@ -1300,7 +1290,7 @@ func migrateStatusRun(cmd *cobra.Command, _ []string, flags migrateStatusFlags)
 		Client: client,
 		Dir:    dir,
 		Schema: revisionSchemaName(client, flags.revisionSchema),
-	}).Report(cmd.Context())
+	}).Report(ctx)
 	if err != nil {
 		return err
 	}
@@ -1366,7 +1356,7 @@ func migrateValidateRun(cmd *cobra.Command, _ []string, flags migrateValidateFla
 	}
 	defer dev.Close()
 	// Currently, only our own migration file format is supported.
-	dir, err := cmdmigrate.Dir(flags.dirURL, false)
+	dir, err := cmdmigrate.Dir(cmd.Context(), flags.dirURL, false)
 	if err != nil {
 		return err
 	}
@@ -1591,7 +1581,7 @@ func dirFormatBC(flag string, urls ...*string) error {
 }
 
 func checkDir(cmd *cobra.Command, url string, create bool) error {
-	d, err := cmdmigrate.Dir(url, create)
+	d, err := cmdmigrate.Dir(cmd.Context(), url, create)
 	if err != nil {
 		return err
 	}
@@ -1708,7 +1698,7 @@ func setMigrateEnvFlags(cmd *cobra.Command, env *Env) error {
 		if err := maySetFlag(cmd, flagLockTimeout, env.Migration.LockTimeout); err != nil {
 			return err
 		}
-	case "diff":
+	case "diff", "checkpoint":
 		if err := maySetFlag(cmd, flagLockTimeout, env.Migration.LockTimeout); err != nil {
 			return err
 		}
