@@ -812,17 +812,19 @@ func TestMigrate_ApplyCloudReport(t *testing.T) {
 				// Archive and send.
 				arc, err := migrate.ArchiveDir(&dir)
 				require.NoError(t, err)
-				fmt.Fprintf(w, `{"data":{"dir":{"content":%q}}}`, base64.StdEncoding.EncodeToString(arc))
+				fmt.Fprintf(w, `{"data":{"dirState":{"content":%q}}}`, base64.StdEncoding.EncodeToString(arc))
 			case strings.Contains(m.Query, "mutation") && strings.Contains(m.Query, "ReportMigrationSet"):
 				if status != 0 {
 					w.WriteHeader(status)
 				}
 				require.NoError(t, json.Unmarshal(m.Variables.Input, &reports))
+				fmt.Fprint(w, `{"data":{"reportMigrationSet":{"url": "https://gh.atlasgo.cloud/deployments/sets/94489280524"}}}`)
 			case strings.Contains(m.Query, "mutation") && strings.Contains(m.Query, "ReportMigration"):
 				if status != 0 {
 					w.WriteHeader(status)
 				}
 				require.NoError(t, json.Unmarshal(m.Variables.Input, &report))
+				fmt.Fprint(w, `{"data":{"reportMigration":{"url": "https://gh.atlasgo.cloud/deployments/51539607559"}}}`)
 			default:
 				t.Fatalf("unexpected query: %s", m.Query)
 			}
@@ -869,7 +871,7 @@ env {
 			"--var", "cloud_url="+srv.URL,
 		)
 		require.NoError(t, err)
-		require.Equal(t, "No migration files to execute\n", s)
+		require.Equal(t, "No migration files to execute\nhttps://gh.atlasgo.cloud/deployments/51539607559\n", s)
 		require.NotEmpty(t, report.Target.ID)
 		_, err = uuid.Parse(report.Target.ID)
 		require.NoError(t, err, "target id is not a valid uuid")
@@ -908,7 +910,7 @@ env {
 		require.NoError(t, err)
 		// Reporting does not affect the output.
 		require.True(t, strings.HasPrefix(s, "Migrating to version 2 (2 migrations in total):"))
-		require.True(t, strings.HasSuffix(s, "  -- 2 migrations \n  -- 2 sql statements\n"))
+		require.True(t, strings.HasSuffix(s, "  -- 2 migrations \n  -- 2 sql statements\nhttps://gh.atlasgo.cloud/deployments/51539607559\n"))
 		require.Equal(t, "", report.FromVersion, "from empty database")
 		require.Equal(t, "2", report.ToVersion)
 		require.Equal(t, "2", report.CurrentVersion)
@@ -994,10 +996,12 @@ func TestMigrate_ApplyCloudReportSet(t *testing.T) {
 				// Archive and send.
 				arc, err := migrate.ArchiveDir(&dir)
 				require.NoError(t, err)
-				fmt.Fprintf(w, `{"data":{"dir":{"content":%q}}}`, base64.StdEncoding.EncodeToString(arc))
+				fmt.Fprintf(w, `{"data":{"dirState":{"content":%q}}}`, base64.StdEncoding.EncodeToString(arc))
 			case strings.Contains(m.Query, "mutation"):
 				if status != 0 {
 					w.WriteHeader(status)
+				} else {
+					fmt.Fprint(w, `{"data":{"reportMigrationSet":{"url":"https://gh.atlasgo.cloud/deployments/sets/94489280524"}}}`)
 				}
 				require.NoError(t, json.Unmarshal(m.Variables.Input, &report))
 			default:
@@ -1053,7 +1057,7 @@ env {
 			"--var", "cloud_url="+srv.URL,
 		)
 		require.NoError(t, err)
-		require.Equal(t, "No migration files to execute\nNo migration files to execute\n", s)
+		require.Equal(t, "No migration files to execute\nNo migration files to execute\nhttps://gh.atlasgo.cloud/deployments/sets/94489280524\n", s)
 		require.NotEmpty(t, report.ID)
 		_, err = uuid.Parse(report.ID)
 		require.NoError(t, err, "set id is not a valid uuid")
@@ -1979,3 +1983,7 @@ func sed(t *testing.T, r, p string) {
 	buf, err := exec.Command("sed", append(args, r, p)...).CombinedOutput()
 	require.NoError(t, err, string(buf))
 }
+
+func lines(f migrate.File) []string {
+	return strings.Split(strings.TrimSpace(string(f.Bytes())), "\n")
+}
