@@ -29,6 +29,9 @@ import (
 	"ariga.io/atlas/sql/schema"
 	"ariga.io/atlas/sql/sqlclient"
 	"ariga.io/atlas/sql/sqltool"
+	"github.com/aws/aws-sdk-go-v2/config"
+	"github.com/aws/aws-sdk-go-v2/feature/rds/auth"
+
 	"github.com/zclconf/go-cty/cty/gocty"
 
 	"entgo.io/ent/dialect/sql"
@@ -55,6 +58,7 @@ var DataSources = []schemahcl.Option{
 	schemahcl.WithDataSource("remote_dir", RemoteDir),
 	schemahcl.WithDataSource("hcl_schema", SchemaHCL),
 	schemahcl.WithDataSource("external_schema", SchemaExternal),
+	schemahcl.WithDataSource("aws_rds_token", AWSRDSToken),
 }
 
 // RuntimeVar exposes the gocloud.dev/runtimevar as a schemahcl datasource.
@@ -113,6 +117,40 @@ func RuntimeVar(c *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
 	return cty.StringVal(sv), nil
 }
 
+// AWSRDSToken exposes an AWS RDS token as a schemahcl datasource.
+//
+//	data "aws_rds_token" "token" {
+//		endpoint = "db.hostname.io:3306"
+//		region   = "us-east-1"
+//		username = "admin"
+//	}
+func AWSRDSToken(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, error) {
+	var (
+		args struct {
+			Endpoint string `hcl:"endpoint"`
+			Region   string `hcl:"region,optional"`
+			Username string `hcl:"username"`
+		}
+		errorf = blockError("data.aws_rds_token", block)
+	)
+	if diags := gohcl.DecodeBody(block.Body, ctx, &args); diags.HasErrors() {
+		return cty.NilVal, errorf("decoding body: %v", diags)
+	}
+	bgctx := context.Background()
+	cfg, err := config.LoadDefaultConfig(bgctx)
+	if err != nil {
+		return cty.NilVal, errorf("loading aws config: %v", err)
+	}
+	if args.Region == "" {
+		args.Region = cfg.Region
+	}
+	token, err := auth.BuildAuthToken(bgctx, args.Endpoint, args.Region, args.Username, cfg.Credentials)
+	if err != nil {
+		return cty.NilVal, errorf("building auth token: %v", err)
+	}
+	return cty.StringVal(token), nil
+}
+
 // Query exposes the database/sql.Query as a schemahcl datasource.
 //
 //	data "sql" "tenants" {
@@ -360,9 +398,6 @@ type AtlasConfig struct {
 	Project string           // Optional project.
 }
 
-// DefaultProjectName is the default name for projects.
-const DefaultProjectName = "default"
-
 // InitBlock returns the handler for the "atlas" init block.
 //
 //	atlas {
@@ -385,7 +420,7 @@ func (c *AtlasConfig) InitBlock() schemahcl.Option {
 			return cty.NilVal, fmt.Errorf("atlas.cloud: decoding body: %v", diags)
 		}
 		if args.Cloud.Project == "" {
-			args.Cloud.Project = DefaultProjectName
+			args.Cloud.Project = cloudapi.DefaultProjectName
 		}
 		c.Project = args.Cloud.Project
 		c.Client = cloudapi.New(args.Cloud.URL, args.Cloud.Token)
@@ -534,16 +569,16 @@ func SchemaExternal(ctx *hcl.EvalContext, block *hclsyntax.Block) (cty.Value, er
 	}), nil
 }
 
-func memdir(client *cloudapi.Client, dirName string, tag string) (string, error) {
-	input := cloudapi.DirInput{
-		Name: dirName,
+// memdir converts the given (cloud) migrate.Dir to a memory migrate.Dir.
+func memdir(client *cloudapi.Client, name, tag string) (string, error) {
+	dir, err := client.Dir(context.Background(), cloudapi.DirInput{
+		Name: name,
 		Tag:  tag,
-	}
-	dir, err := client.Dir(context.Background(), input)
+	})
 	if err != nil {
 		return "", err
 	}
-	md := migrate.OpenMemDir(dirName)
+	md := migrate.OpenMemDir(name)
 	files, err := dir.Files()
 	if err != nil {
 		return "", err
@@ -562,7 +597,7 @@ func memdir(client *cloudapi.Client, dirName string, tag string) (string, error)
 			return "", err
 		}
 	}
-	return "mem://" + dirName, nil
+	return "mem://" + name, nil
 }
 
 func blockError(name string, b *hclsyntax.Block) func(string, ...any) error {
