@@ -7,8 +7,10 @@ package schemahcl
 import (
 	"fmt"
 	"net/url"
+	"path/filepath"
 	"testing"
 
+	"github.com/stretchr/testify/require"
 	"github.com/zclconf/go-cty/cty"
 )
 
@@ -108,3 +110,50 @@ func TestURLEscapeFunc(t *testing.T) {
 		})
 	}
 }
+
+func TestMakeFileFunc(t *testing.T) {
+	fn := MakeFileFunc("testdata")
+	_, err := fn.Call([]cty.Value{cty.StringVal("foo")})
+	require.EqualError(t, err, "base directory must be an absolute path. got: testdata")
+	base, err := filepath.Abs("testdata")
+	require.NoError(t, err)
+	fn = MakeFileFunc(base)
+	v, err := fn.Call([]cty.Value{cty.StringVal("a.hcl")})
+	require.NoError(t, err)
+	require.Equal(t, "person \"rotemtam\" {\n  hobby = var.hobby\n}", v.AsString())
+}
+
+func Example_PrintFunc() {
+	for _, f := range []string{
+		`v  = print(1)`,
+		`v  = print(true)`,
+		`v  = print("hello, world")`,
+		`v  = print({"hello": "world"})`,
+		`v  = print(["hello", "world"])`,
+	} {
+		var d struct {
+			V cty.Value `spec:"v"`
+		}
+		if err := New().EvalBytes([]byte(f), &d, nil); err != nil {
+			fmt.Println("failed to evaluate:", err)
+			return
+		}
+		fmt.Printf("%#v\n\n", d.V)
+	}
+	// Output:
+	// 1
+	// cty.NumberIntVal(1)
+	//
+	// true
+	// cty.True
+	//
+	// "hello, world"
+	// cty.StringVal("hello, world")
+	//
+	// {"hello":"world"}
+	// cty.ObjectVal(map[string]cty.Value{"hello":cty.StringVal("world")})
+	//
+	// ["hello","world"]
+	// cty.ListVal([]cty.Value{cty.StringVal("hello"), cty.StringVal("world")})
+	//
+}
