@@ -7,7 +7,7 @@ package specutil
 import (
 	"testing"
 
-	"ariga.io/atlas/schema/schemaspec"
+	"ariga.io/atlas/schemahcl"
 	"ariga.io/atlas/sql/schema"
 	"ariga.io/atlas/sql/sqlspec"
 
@@ -22,12 +22,18 @@ func TestFromSpec_SchemaName(t *testing.T) {
 		},
 	}
 	sc.Tables[0].Schema = sc
-	s, ta, err := FromSchema(sc, func(table *schema.Table) (*sqlspec.Table, error) {
-		return &sqlspec.Table{}, nil
-	})
+	spec, err := FromSchema(
+		sc,
+		func(*schema.Table) (*sqlspec.Table, error) {
+			return &sqlspec.Table{}, nil
+		},
+		func(*schema.View) (*sqlspec.View, error) {
+			return &sqlspec.View{}, nil
+		},
+	)
 	require.NoError(t, err)
-	require.Equal(t, sc.Name, s.Name)
-	require.Equal(t, "$schema."+sc.Name, ta[0].Schema.V)
+	require.Equal(t, sc.Name, spec.Schema.Name)
+	require.Equal(t, "$schema."+sc.Name, spec.Tables[0].Schema.V)
 }
 
 func TestFromForeignKey(t *testing.T) {
@@ -65,14 +71,14 @@ func TestFromForeignKey(t *testing.T) {
 	require.NoError(t, err)
 	require.EqualValues(t, &sqlspec.ForeignKey{
 		Symbol: "fk",
-		Columns: []*schemaspec.Ref{
+		Columns: []*schemahcl.Ref{
 			{V: "$column.parent_id"},
 		},
-		RefColumns: []*schemaspec.Ref{
+		RefColumns: []*schemahcl.Ref{
 			{V: "$column.id"},
 		},
-		OnUpdate: &schemaspec.Ref{V: "NO_ACTION"},
-		OnDelete: &schemaspec.Ref{V: "CASCADE"},
+		OnUpdate: &schemahcl.Ref{V: "NO_ACTION"},
+		OnDelete: &schemahcl.Ref{V: "CASCADE"},
 	}, key)
 
 	fk.OnDelete = ""
@@ -81,10 +87,10 @@ func TestFromForeignKey(t *testing.T) {
 	require.NoError(t, err)
 	require.EqualValues(t, &sqlspec.ForeignKey{
 		Symbol: "fk",
-		Columns: []*schemaspec.Ref{
+		Columns: []*schemahcl.Ref{
 			{V: "$column.parent_id"},
 		},
-		RefColumns: []*schemaspec.Ref{
+		RefColumns: []*schemahcl.Ref{
 			{V: "$column.id"},
 		},
 	}, key)
